misfit package
==============

.. include:: ../misfit/__init__.py
   :start-after: """
   :end-before: """

Submodules
----------

misfit.auth module
^^^^^^^^^^^^^^^^^^

.. automodule:: misfit.auth

misfit.misfit module
^^^^^^^^^^^^^^^^^^^^

.. automodule:: misfit.misfit

misfit.cli module
^^^^^^^^^^^^^^^^^

.. literalinclude:: ../misfit/cli.py
   :start-after: """
   :end-before: """
.. autoclass:: misfit.cli.MisfitCli

misfit.notification module
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: misfit.notification

misfit.exceptions module
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: misfit.exceptions
